@@ -191,7 +191,7 @@ end
 
 function tightspot_update_spending(tightspot)
   local available
-  if game.players[1].controller_type == defines.controllers.god then
+  if game.players[1].controller_type ~= defines.controllers.ghost then
     available = game.players[1].get_item_count("coin")
   else
     available = tightspot.available
@@ -219,7 +219,15 @@ function tightspot_sell_back(tightspot)
   tightspot.debt = tightspot.debt - addition
 end
 
+function leave_remote_controller(player)
+  if player.controller_type == defines.controllers.remote then
+    player.teleport(player.position, player.surface) -- trick to quit remote controller in a way that preserves god controller inventory. set_controller was getting rid of coins
+    assert(player.controller_type ~= defines.controllers.remote)
+  end
+end
+
 function tightspot_start_level(tightspot)
+  leave_remote_controller(game.players[1])
   map_save()
   tightspot_sell_back(tightspot)
   mod_gui.get_button_flow(game.players[1]).tightspot_start.destroy()
