@@ -320,7 +320,7 @@ data:extend({
   working_sound =
   {
     sound = {category = "weapon", filename = "__base__/sound/fire-1.ogg"},
-    max_sounds_per_type = 2
+    max_sounds_per_prototype = 2
   }
 }})
 
@@ -374,8 +374,8 @@ data:extend({
     selection_box = {{-1, -1.5 }, {1, 1.5}},
     rotation_speed = 0.015,
     preparing_speed = 0.08,
-    open_sound = {filename = "__base__/sound/open-close/turret-open.ogg", volume = 0.6},
-    close_sound = {filename = "__base__/sound/open-close/turret-close.ogg", volume = 0.6},
+    open_sound = sounds.turret_open,
+    close_sound = sounds.turret_close,
     preparing_sound = sounds.flamethrower_turret_activate,
     folding_sound = sounds.flamethrower_turret_deactivate,
     folding_speed = 0.08,
@@ -440,8 +440,8 @@ data:extend({
     {
       base_visualisation =
       {
-        render_layer = "lower-object-above-shadow",
-        secondary_draw_order = 1,
+        render_layer = "object",
+        secondary_draw_order = 0,
         animation =
         {
           north =
@@ -489,8 +489,8 @@ data:extend({
                 filename = "__base__/graphics/entity/flamethrower-turret/flamethrower-turret-base-east.png",
                 line_length = 1,
                 width = 216,
-                height = 146,
-                shift = util.by_pixel(-6, 3),
+                height = 169,
+                shift = util.by_pixel(-6, -2.75),
                 scale = 0.5
               },
               -- mask
@@ -562,8 +562,8 @@ data:extend({
                 filename = "__base__/graphics/entity/flamethrower-turret/flamethrower-turret-base-west.png",
                 line_length = 1,
                 width = 208,
-                height = 144,
-                shift = util.by_pixel(7, -1),
+                height = 160,
+                shift = util.by_pixel(7, -5),
                 scale = 0.5
               },
               -- mask
