@@ -349,7 +349,13 @@ data:extend
         height = 192,
         scale = 0.5
       }
-    }
+    },
+    circuit_wire_max_distance = splitter_circuit_wire_max_distance,
+    circuit_connector = circuit_connector_definitions["splitter"],
+    default_input_left_condition = { first = {type="virtual", name="signal-I"}, comparator="<", second=0},
+    default_input_right_condition = { first = {type="virtual", name="signal-I"}, comparator=">", second=0},
+    default_output_left_condition = { first = {type="virtual", name="signal-O"}, comparator="<", second=0},
+    default_output_right_condition = { first = {type="virtual", name="signal-O"}, comparator=">", second=0},
   },
   {
     type = "loader",
