@@ -189,8 +189,207 @@ local eruption_smoke_trigger_effect = function()
   }
 end
 
+local small_grey_smoke_trigger_effect = function()
+  return
+  {
+    type = "create-trivial-smoke",
+    smoke_name = "space-platform-explosion-particle-smoke",
+    starting_frame_deviation = 0.5,
+    offset_deviation = {{-0.03, -0.03}, {0.03, 0.03}},
+    speed_from_center = 0.01,
+    speed_from_center_deviation = 0.02
+  }
+end
+
+local small_grey_dust_smoke_trigger_effect = function()
+  return
+  {
+    type = "create-trivial-smoke",
+    smoke_name = "small-dust-particle-smoke",
+    starting_frame_deviation = 0.5,
+    offset_deviation = {{-0.03, -0.03}, {0.03, 0.03}},
+    speed_from_center = 0.01,
+    speed_from_center_deviation = 0.02
+  }
+end
+
+local gleba_tree_pink_smoke_trigger_effect = function()
+  return
+  {
+    type = "create-trivial-smoke",
+    smoke_name = "gleba-tree-particle-smoke-pink",
+    starting_frame_deviation = 0,
+    offset_deviation = {{-0.03, -0.03}, {0.03, 0.03}},
+    speed_from_center = nil
+  }
+end
+
+local gleba_tree_red_smoke_trigger_effect = function()
+  return
+  {
+    type = "create-trivial-smoke",
+    smoke_name = "gleba-tree-particle-smoke-red",
+    starting_frame_deviation = 0,
+    offset_deviation = {{-0.03, -0.03}, {0.03, 0.03}},
+    speed_from_center = nil
+  }
+end
+
+local gleba_tree_blue_smoke_trigger_effect = function()
+  return
+  {
+    type = "create-trivial-smoke",
+    smoke_name = "gleba-tree-particle-smoke-blue",
+    starting_frame_deviation = 0,
+    offset_deviation = {{-0.03, -0.03}, {0.03, 0.03}},
+    speed_from_center = nil
+  }
+end
+
+local gleba_tree_orange_smoke_trigger_effect = function()
+  return
+  {
+    type = "create-trivial-smoke",
+    smoke_name = "gleba-tree-particle-smoke-orange",
+    starting_frame_deviation = 0,
+    offset_deviation = {{-0.03, -0.03}, {0.03, 0.03}},
+    speed_from_center = nil
+  }
+end
+
 local particle_counter = 0
 
+local gleba_tree_grey_sap_trigger_effect = function()
+  return
+  {
+    {
+      type = "create-particle",
+      probability = 0.5,
+      affects_target = false,
+      show_in_tooltip = false,
+      particle_name = "gleba-tree-sap-particle-trigger-grey",
+      offset_deviation = { { -0.02, -0.02 }, { 0.02, 0.02 } },
+      initial_height = 0,
+      initial_height_deviation = 0.01,
+      initial_vertical_speed = 0,
+      initial_vertical_speed_deviation = 0.00,
+      speed_from_center = 0.01,
+      speed_from_center_deviation = 0.02,
+      frame_speed = 1,
+      frame_speed_deviation = 0,
+      tail_length = 2,
+      tail_length_deviation = 1,
+      tail_width = 4,
+      only_when_visible = true
+    }
+  }
+end
+
+local gleba_tree_red_sap_trigger_effect = function()
+  return
+  {
+    {
+      type = "create-particle",
+      probability = 0.5,
+      affects_target = false,
+      show_in_tooltip = false,
+      particle_name = "gleba-tree-sap-particle-trigger-red",
+      offset_deviation = { { -0.02, -0.02 }, { 0.02, 0.02 } },
+      initial_height = 0,
+      initial_height_deviation = 0.01,
+      initial_vertical_speed = 0,
+      initial_vertical_speed_deviation = 0.00,
+      speed_from_center = 0.01,
+      speed_from_center_deviation = 0.02,
+      frame_speed = 1,
+      frame_speed_deviation = 0,
+      tail_length = 2,
+      tail_length_deviation = 1,
+      tail_width = 4,
+      only_when_visible = true
+    }
+  }
+end
+
+local gleba_tree_blue_sap_trigger_effect = function()
+  return
+  {
+    {
+      type = "create-particle",
+      probability = 0.4,
+      affects_target = false,
+      show_in_tooltip = false,
+      particle_name = "gleba-tree-sap-particle-trigger-blue",
+      offset_deviation = { { -0.001, -0.001 }, { 0.001, 0.001 } },
+      initial_height = 0,
+      initial_height_deviation = 0.001,
+      initial_vertical_speed = 0,
+      initial_vertical_speed_deviation = 0.00,
+      speed_from_center = 0.01,
+      speed_from_center_deviation = 0,
+      frame_speed = 1,
+      frame_speed_deviation = 0,
+      tail_length = 2,
+      tail_length_deviation = 0,
+      tail_width = 1,
+      only_when_visible = true
+    }
+  }
+end
+
+local gleba_tree_green_sap_trigger_effect = function()
+  return
+  {
+    {
+      type = "create-particle",
+      probability = 0.5,
+      affects_target = false,
+      show_in_tooltip = false,
+      particle_name = "gleba-tree-sap-particle-trigger-green",
+      offset_deviation = { { -0.02, -0.02 }, { 0.02, 0.02 } },
+      initial_height = 0,
+      initial_height_deviation = 0.01,
+      initial_vertical_speed = 0,
+      initial_vertical_speed_deviation = 0.00,
+      speed_from_center = 0.01,
+      speed_from_center_deviation = 0.02,
+      frame_speed = 1,
+      frame_speed_deviation = 0,
+      tail_length = 2,
+      tail_length_deviation = 1,
+      tail_width = 4,
+      only_when_visible = true
+    }
+  }
+end
+
+local gleba_tree_leaf_trigger_effect = function()
+  return
+  {
+    {
+      type = "create-particle",
+      probability = 0.1,
+      repeat_count = 1,
+      affects_target = false,
+      show_in_tooltip = false,
+      particle_name = "gleba-tree-leaf-particle-trigger",
+      offset_deviation = { { -0.02, -0.02 }, { 0.02, 0.02 } },
+      initial_height = 0,
+      initial_height_deviation = 0.01,
+      initial_vertical_speed = 0,
+      initial_vertical_speed_deviation = 0.00,
+      speed_from_center = 0.01,
+      speed_from_center_deviation = 0.02,
+      frame_speed = 1,
+      frame_speed_deviation = 0.5,
+      tail_length = 1,
+      tail_length_deviation = 1,
+      tail_width = 1,
+      only_when_visible = true
+    }
+  }
+end
+
 local default_ended_in_lava_trigger_effect = function()
   return
   {
@@ -213,6 +412,7 @@ local default_ended_in_lava_trigger_effect = function()
       tail_length = 2,
       tail_length_deviation = 1,
       tail_width = 3,
+      only_when_visible = true
     },
     {
       type = "create-particle",
@@ -241,7 +441,8 @@ local default_ended_in_lava_trigger_effect = function()
       frame_speed_deviation = 0,
       tail_length = 9,
       tail_length_deviation = 0.5,
-      tail_width = 4
+      tail_width = 4,
+      only_when_visible = true
     },
     {
       type = "play-sound",
@@ -273,7 +474,8 @@ local default_ended_in_water_trigger_effect = function()
       frame_speed_deviation = 0,
       tail_length = 2,
       tail_length_deviation = 1,
-      tail_width = 3
+      tail_width = 3,
+      only_when_visible = true
     },
     {
       type = "create-particle",
@@ -302,7 +504,8 @@ local default_ended_in_water_trigger_effect = function()
       frame_speed_deviation = 0,
       tail_length = 9,
       tail_length_deviation = 0,
-      tail_width = 1
+      tail_width = 1,
+      only_when_visible = true
     },
     {
       type = "play-sound",
@@ -318,7 +521,7 @@ local particle_ended_in_water_trigger_effect = function()
     type = "create-particle",
     repeat_count = 5,
     repeat_count_deviation = 4,
-    probability = 0.2,
+    probability = 0.05,
     affects_target = false,
     show_in_tooltip = false,
     particle_name = "tintable-water-particle",
@@ -336,7 +539,8 @@ local particle_ended_in_water_trigger_effect = function()
     frame_speed_deviation = 0,
     tail_length = 9,
     tail_length_deviation = 8,
-    tail_width = 1
+    tail_width = 1,
+    only_when_visible = true
   }
 end
 
@@ -419,7 +623,7 @@ local particles =
     name = "turbo-underground-belt-metal-particle-medium-green",
     pictures = particle_animations.get_metal_particle_medium_pictures ({tint = {0.4235, 0.827, 0.310, 1}}),
     shadows = particle_animations.get_metal_particle_medium_pictures({ tint = shadowtint(), shift = util.by_pixel (1,0)}),
-    regular_trigger_effect = small_smoke_trigger_effect(),
+    regular_trigger_effect = small_grey_dust_smoke_trigger_effect(),
     ended_in_water_trigger_effect = default_ended_in_water_trigger_effect()
   },
   make_particle
@@ -436,7 +640,7 @@ local particles =
     name = "turbo-transport-belt-mechanical-component-particle-medium",
     pictures = particle_animations.get_mechanical_component_particle_medium_pictures({tint = {0.859, 0.766, 0.680, 1}}),
     shadows = particle_animations.get_mechanical_component_particle_medium_pictures({ tint = shadowtint(), shift = util.by_pixel (1,0)}),
-    regular_trigger_effect = small_smoke_trigger_effect(),
+    regular_trigger_effect = small_grey_dust_smoke_trigger_effect(),
     ended_in_water_trigger_effect = default_ended_in_water_trigger_effect()
   },
   make_particle
@@ -444,7 +648,7 @@ local particles =
     name = "turbo-transport-belt-metal-particle-medium",
     pictures = particle_animations.get_metal_particle_medium_pictures ({tint = {0.2, 0.816, 0.24, 1}}),
     shadows = particle_animations.get_metal_particle_medium_pictures({ tint = shadowtint(), shift = util.by_pixel (1,0)}),
-    regular_trigger_effect = small_smoke_trigger_effect(),
+    regular_trigger_effect = small_grey_dust_smoke_trigger_effect(),
     ended_in_water_trigger_effect = default_ended_in_water_trigger_effect()
   },
 
@@ -1123,7 +1327,7 @@ local particles =
     render_layer_when_on_ground = "lower-object-above-shadow",
     render_layer = "object",
   },
-  
+
   make_particle
   {
     name = "vulcanus-lava-particle-long-life-small",
@@ -1152,7 +1356,7 @@ local particles =
 
   make_particle
   {
-      name = "demolisher-skin-particle-small", 
+      name = "demolisher-skin-particle-small",
       life_time = 300,
       pictures = particle_animations.get_demolisher_skin_particles_small(),
       shadows = particle_animations.get_demolisher_skin_particles_small({ tint = shadowtint(), shift = util.by_pixel(1, 0)}),
@@ -1161,7 +1365,7 @@ local particles =
   },
   make_particle
   {
-      name = "demolisher-skin-particle-medium", 
+      name = "demolisher-skin-particle-medium",
       life_time = 250,
       pictures = particle_animations.get_demolisher_skin_particles_medium(),
       shadows = particle_animations.get_demolisher_skin_particles_medium({ tint = shadowtint(), shift = util.by_pixel(1, 0)}),
@@ -1170,7 +1374,7 @@ local particles =
   },
   make_particle
   {
-      name = "demolisher-skin-particle-big",  
+      name = "demolisher-skin-particle-big",
       life_time = 200,
       pictures = particle_animations.get_demolisher_skin_particles_big(),
       shadows = particle_animations.get_demolisher_skin_particles_big({ tint = shadowtint(), shift = util.by_pixel(1, 0)}),
@@ -1179,7 +1383,7 @@ local particles =
   },
   make_particle
   {
-      name = "demolisher-shell-particle-small", 
+      name = "demolisher-shell-particle-small",
       life_time = 70,
       pictures = particle_animations.get_demolisher_shell_particles_small(),
       shadows = particle_animations.get_demolisher_shell_particles_small({ tint = shadowtint(), shift = util.by_pixel(1, 0)}),
@@ -1188,19 +1392,532 @@ local particles =
   },
   make_particle
   {
-      name = "demolisher-shell-particle-big",  
+      name = "demolisher-shell-particle-big",
       life_time = 60,
       pictures = particle_animations.get_demolisher_shell_particles_big(),
       shadows = particle_animations.get_demolisher_shell_particles_big({ tint = shadowtint(), shift = util.by_pixel(1, 0)}),
       ended_in_water_trigger_effect = default_ended_in_water_trigger_effect(),
       render_layer_when_on_ground = "lower-object-above-shadow"
-  }
+  },
+  ------------------------------------------------
 
+  make_particle
+  {
+    name = "space-platform-foundation-particle-small",
+    life_time = 150,
+    pictures = particle_animations.get_metal_particle_small_pictures({tint = {0.859, 0.766, 0.680, 1}}),
+    shadows = particle_animations.get_metal_particle_small_pictures({ tint = shadowtint(), shift = util.by_pixel (1,0)}),
+    regular_trigger_effect = nil,
+    ended_in_water_trigger_effect = default_ended_in_water_trigger_effect(),
+    render_layer = "lower-object-above-shadow"
+  },
+
+  make_particle
+  {
+    name = "space-platform-foundation-particle-medium",
+    life_time = 180,
+    pictures = particle_animations.get_metal_particle_medium_pictures ({tint = {0.350, 0.369, 0.332, 1}}),
+    shadows = particle_animations.get_metal_particle_medium_pictures({ tint = shadowtint(), shift = util.by_pixel (1,0)}),
+    regular_trigger_effect = small_grey_smoke_trigger_effect(),
+    ended_in_water_trigger_effect = default_ended_in_water_trigger_effect(),
+    render_layer = "lower-object-above-shadow"
+  },
+  make_particle
+  {
+    name = "space-platform-foundation-particle-big",
+    life_time = 200,
+    pictures = particle_animations.get_metal_particle_big_pictures ({tint = {0.349, 0.369, 0.333, 1}}),
+    shadows = particle_animations.get_metal_particle_big_pictures({ tint = shadowtint(), shift = util.by_pixel (1,0)}),
+    regular_trigger_effect = small_grey_smoke_trigger_effect(),
+    ended_in_water_trigger_effect = default_ended_in_water_trigger_effect(),
+    render_layer = "lower-object-above-shadow"
+  },
+
+  --GLEBA-TREE-PARTICLES-------------------------
+
+  --trigger-effects
+  make_particle
+  {
+    name = "gleba-tree-sap-particle-trigger-grey",
+    life_time = 60,
+    pictures = particle_animations.get_slipstack_sap_particle_pictures({tint = {0.3686, 0.451, 0.4627, 1.0}, tint_as_overlay = true, scale = 0.8}),
+    shadows = particle_animations.get_slipstack_sap_particle_pictures({ tint = shadowtint(), shift = util.by_pixel (1,0), scale = 0.8}),
+    draw_shadow_when_on_ground = false,
+    ended_in_water_trigger_effect = particle_ended_in_water_trigger_effect(),
+    movement_modifier_when_on_ground = 0,
+    render_layer = "higher-object-under"
+  },
+
+  make_particle
+  {
+    name = "gleba-tree-sap-particle-trigger-red",
+    life_time = 60,
+    pictures = particle_animations.get_gleba_tree_sap_particle_pictures({tint = {0.4196, 0.1412, 0.1216, 1.0}, tint_as_overlay = true, scale = 0.8}),
+    shadows = particle_animations.get_gleba_tree_sap_particle_pictures({ tint = shadowtint(), shift = util.by_pixel (1,0), scale = 0.8}),
+    draw_shadow_when_on_ground = false,
+    ended_in_water_trigger_effect = particle_ended_in_water_trigger_effect(),
+    movement_modifier_when_on_ground = 0,
+    render_layer = "higher-object-under"
+  },
+
+  make_particle
+  {
+    name = "gleba-tree-sap-particle-trigger-blue",
+    life_time = 60,
+    pictures = particle_animations.get_slipstack_sap_particle_pictures({tint = {0.2, 0.3294, 0.349, 1.0}, tint_as_overlay = true, scale = 0.8}),
+    shadows = particle_animations.get_slipstack_sap_particle_pictures({ tint = shadowtint(), shift = util.by_pixel (1,0), scale = 0.8}),
+    draw_shadow_when_on_ground = false,
+    ended_in_water_trigger_effect = particle_ended_in_water_trigger_effect(),
+    movement_modifier_when_on_ground = 0,
+    render_layer = "higher-object-under"
+  },
+
+  make_particle
+  {
+    name = "gleba-tree-sap-particle-trigger-green",
+    life_time = 60,
+    pictures = particle_animations.get_gleba_tree_sap_particle_pictures({tint = {0.5373, 0.5333, 0.1608, 1.0}, tint_as_overlay = true, scale = 0.8}),
+    shadows = particle_animations.get_gleba_tree_sap_particle_pictures({ tint = shadowtint(), shift = util.by_pixel (1,0), scale = 0.8}),
+    draw_shadow_when_on_ground = false,
+    ended_in_water_trigger_effect = particle_ended_in_water_trigger_effect(),
+    movement_modifier_when_on_ground = 0,
+    render_layer = "higher-object-under"
+  },
+
+  make_particle
+  {
+    name = "gleba-tree-leaf-particle-trigger",
+    life_time = 60,
+    pictures = particle_animations.get_gleba_tree_leaf_particle_2_pictures({tint = {0.8118, 0.4392, 0.4471, 1.0}, tint_as_overlay = true, scale = 0.8}),
+    shadows = particle_animations.get_gleba_tree_leaf_particle_2_pictures({ tint = shadowtint(), shift = util.by_pixel (1,0), scale = 0.75}),
+    draw_shadow_when_on_ground = false,
+    ended_in_water_trigger_effect = particle_ended_in_water_trigger_effect(),
+    movement_modifier_when_on_ground = 0,
+    render_layer = "higher-object-under"
+  },
+
+  --Yumako-tree
+
+  make_particle
+  {
+    name = "yumako-leaf-particle",
+    life_time = 120,
+    pictures = particle_animations.get_gleba_tree_crop_particle_pictures({tint = {0.8235, 0.3373, 0.2627, 1.0}, tint_as_overlay = true, scale = 0.7}),
+    shadows = particle_animations.get_gleba_tree_crop_particle_pictures({ tint = shadowtint(),scale = 0.8, shift = util.by_pixel (1,0), scale = 0.7}),
+    regular_trigger_effect_frequency = 6,
+    regular_trigger_effect = gleba_tree_red_sap_trigger_effect(),
+    ended_in_water_trigger_effect = particle_ended_in_water_trigger_effect(),
+    render_layer_when_on_ground = "lower-object-above-shadow"
+  },
+
+  make_particle
+  {
+    name = "yumako-branch-particle",
+    life_time = 120,
+    pictures = particle_animations.get_gleba_tree_wooden_particle_pictures({tint = {0.6039, 0.4314, 0.2157, 1.0}, tint_as_overlay = true}),
+    shadows = particle_animations.get_gleba_tree_wooden_particle_pictures({ tint = shadowtint(), shift = util.by_pixel (1,0)}),
+    regular_trigger_effect = nil,
+    ended_in_water_trigger_effect = particle_ended_in_water_trigger_effect(),
+    render_layer_when_on_ground = "lower-object-above-shadow"
+  },
+
+  make_particle
+  {
+    name = "yumako-mining-particle",
+    life_time = 120,
+    pictures = particle_animations.get_gleba_tree_wooden_particle_pictures({tint = {0.6039, 0.4314, 0.2157, 1.0}, tint_as_overlay = true, scale = 0.5}),
+    shadows = particle_animations.get_gleba_tree_wooden_particle_pictures({ tint = shadowtint(), shift = util.by_pixel (1,0), scale = 0.5}),
+    regular_trigger_effect = nil,
+    ended_in_water_trigger_effect = particle_ended_in_water_trigger_effect(),
+    render_layer_when_on_ground = "lower-object-above-shadow"
+  },
+
+  --Jellystem
+
+  make_particle
+  {
+    name = "jellystem-leaf-particle",
+    life_time = 120,
+    pictures = particle_animations.get_gleba_tree_sap_particle_pictures({tint = {0.6314, 0.1765, 0.2824, 1.0}, tint_as_overlay = true, scale = 0.95}),
+    shadows = particle_animations.get_gleba_tree_sap_particle_pictures({ tint = shadowtint(), shift = util.by_pixel (1,0), scale = 0.95}),
+    regular_trigger_effect = nil,
+    ended_in_water_trigger_effect = particle_ended_in_water_trigger_effect(),
+    render_layer_when_on_ground = "lower-object-above-shadow",
+    render_layer = "higher-object-under"
+  },
+
+  make_particle
+  {
+    name = "jellystem-branch-particle",
+    life_time = 120,
+    pictures = particle_animations.get_gleba_tree_crop_particle_pictures({tint = {0.6275, 0.3922, 0.4706, 1.0}, tint_as_overlay = true, scale = 1.2}),
+    shadows = particle_animations.get_gleba_tree_crop_particle_pictures({ tint = shadowtint(), shift = util.by_pixel (1,0), scale = 1.2}),
+    regular_trigger_effect_frequency = 4,
+    regular_trigger_effect = gleba_tree_red_sap_trigger_effect(),
+    ended_in_water_trigger_effect = particle_ended_in_water_trigger_effect(),
+    render_layer_when_on_ground = "lower-object-above-shadow",
+    render_layer = "higher-object-above"
+  },
+
+  make_particle
+  {
+    name = "jellystem-mining-particle",
+    life_time = 120,
+    pictures = particle_animations.get_gleba_tree_crop_particle_pictures({tint = {0.6275, 0.3922, 0.4706, 1.0}, tint_as_overlay = true, scale = 0.5}),
+    shadows = particle_animations.get_gleba_tree_crop_particle_pictures({ tint = shadowtint(), shift = util.by_pixel (1,0), scale = 0.5}),
+    regular_trigger_effect = nil,
+    ended_in_water_trigger_effect = particle_ended_in_water_trigger_effect(),
+    render_layer_when_on_ground = "lower-object-above-shadow"
+  },
+
+  --Cuttlepop
+
+  make_particle
+  {
+    name = "cuttlepop-leaf-particle",
+    life_time = 120,
+    pictures = particle_animations.get_gleba_tree_crop_particle_pictures({tint = {0.6471, 0.5412, 0.8392, 1.0}, tint_as_overlay = true, scale = 0.5}),
+    shadows = particle_animations.get_gleba_tree_crop_particle_pictures({ tint = shadowtint(), shift = util.by_pixel (1,0), scale = 0.5}),
+    regular_trigger_effect = gleba_tree_grey_sap_trigger_effect(),
+    regular_trigger_effect_frequency = 4,
+    ended_in_water_trigger_effect = particle_ended_in_water_trigger_effect(),
+    render_layer_when_on_ground = "lower-object-above-shadow"
+  },
+
+  make_particle
+  {
+    name = "cuttlepop-branch-particle",
+    life_time = 120,
+    pictures = particle_animations.get_gleba_tree_wooden_particle_pictures({tint = {0.651, 0.6118, 0.5922, 1.0}, tint_as_overlay = true, scale = 0.8}),
+    shadows = particle_animations.get_gleba_tree_wooden_particle_pictures({ tint = shadowtint(), shift = util.by_pixel (1,0), scale = 0.8}),
+    regular_trigger_effect = small_dust_smoke_trigger_effect(),
+    ended_in_water_trigger_effect = particle_ended_in_water_trigger_effect(),
+    render_layer_when_on_ground = "lower-object-above-shadow"
+  },
+
+  make_particle
+  {
+    name = "cuttlepop-mining-particle",
+    life_time = 120,
+    pictures = particle_animations.get_gleba_tree_wooden_particle_pictures({tint = {0.651, 0.6118, 0.5922, 1.0}, tint_as_overlay = true, scale = 0.5}),
+    shadows = particle_animations.get_gleba_tree_wooden_particle_pictures({ tint = shadowtint(), shift = util.by_pixel (1,0), scale = 0.5}),
+    regular_trigger_effect = small_dust_smoke_trigger_effect(),
+    ended_in_water_trigger_effect = particle_ended_in_water_trigger_effect(),
+    render_layer_when_on_ground = "lower-object-above-shadow"
+  },
+
+  --slipstack
+
+  make_particle
+  {
+    name = "slipstack-leaf-particle",
+    life_time = 120,
+    pictures = particle_animations.get_slipstack_sap_particle_pictures({tint = {0.2, 0.3294, 0.349, 1.0}, tint_as_overlay = true, scale = 1.5}),
+    shadows = particle_animations.get_slipstack_sap_particle_pictures({ tint = shadowtint(), shift = util.by_pixel (1,0), scale = 1.3}),
+    regular_trigger_effect_frequency = 6,
+    regular_trigger_effect = gleba_tree_blue_sap_trigger_effect(),
+    ended_in_water_trigger_effect = particle_ended_in_water_trigger_effect(),
+    render_layer_when_on_ground = "lower-object-above-shadow"
+  },
+
+  make_particle
+  {
+    name = "slipstack-branch-particle",
+    life_time = 120,
+    pictures = particle_animations.get_gleba_tree_spongy_particle_pictures({tint = {0.6431, 0.498, 0.5451, 1.0}, tint_as_overlay = true, scale = 1.2}),
+    shadows = particle_animations.get_gleba_tree_spongy_particle_pictures({ tint = shadowtint(), shift = util.by_pixel (1,0), scale = 1.2}),
+    regular_trigger_effect = gleba_tree_pink_smoke_trigger_effect(),
+    ended_in_water_trigger_effect = particle_ended_in_water_trigger_effect(),
+    render_layer_when_on_ground = "lower-object-above-shadow"
+  },
+
+  make_particle
+  {
+    name = "slipstack-mining-particle",
+    life_time = 120,
+    pictures = particle_animations.get_gleba_tree_spongy_particle_pictures({tint = {0.6431, 0.498, 0.5451, 1.0}, tint_as_overlay = true, scale = 0.5}),
+    shadows = particle_animations.get_gleba_tree_spongy_particle_pictures({ tint = shadowtint(), shift = util.by_pixel (1,0), scale = 0.5}),
+    regular_trigger_effect = gleba_tree_pink_smoke_trigger_effect(),
+    ended_in_water_trigger_effect = particle_ended_in_water_trigger_effect(),
+    render_layer_when_on_ground = "lower-object-above-shadow"
+  },
+
+  --funneltrunk
+
+  make_particle
+  {
+    name = "funneltrunk-leaf-particle",
+    life_time = 120,
+    pictures = particle_animations.get_gleba_tree_crop_particle_pictures({tint = {0.6902, 0.4627, 0.5608, 1.0}, tint_as_overlay = true, scale = 0.3}),
+    shadows = particle_animations.get_gleba_tree_crop_particle_pictures({ tint = shadowtint(), shift = util.by_pixel (1,0), scale = 0.3}),
+    regular_trigger_effect = nil,
+    ended_in_water_trigger_effect = particle_ended_in_water_trigger_effect(),
+    render_layer_when_on_ground = "lower-object-above-shadow"
+  },
+
+  make_particle
+  {
+    name = "funneltrunk-branch-particle",
+    life_time = 120,
+    pictures = particle_animations.get_gleba_tree_spongy_particle_pictures({tint = {0.4549, 0.3804, 0.1451, 1.0}, tint_as_overlay = true, scale = 1.2}),
+    shadows = particle_animations.get_gleba_tree_spongy_particle_pictures({ tint = shadowtint(), shift = util.by_pixel (1,0), scale = 1.2}),
+    regular_trigger_effect_frequency = 4,
+    regular_trigger_effect = gleba_tree_green_sap_trigger_effect(),
+    ended_in_water_trigger_effect = particle_ended_in_water_trigger_effect(),
+    render_layer_when_on_ground = "lower-object-above-shadow",
+    --render_layer = "higher-object-above"
+  },
+
+  make_particle
+  {
+    name = "funneltrunk-mining-particle",
+    life_time = 120,
+    pictures = particle_animations.get_gleba_tree_spongy_particle_pictures({tint = {0.4549, 0.3804, 0.1451, 1.0}, tint_as_overlay = true, scale = 0.5}),
+    shadows = particle_animations.get_gleba_tree_spongy_particle_pictures({ tint = shadowtint(), shift = util.by_pixel (1,0), scale = 0.5}),
+    regular_trigger_effect = nil,
+    ended_in_water_trigger_effect = particle_ended_in_water_trigger_effect(),
+    render_layer_when_on_ground = "lower-object-above-shadow"
+  },
+
+  --hairyclubnub
+
+  make_particle
+  {
+    name = "hairyclubnub-leaf-particle",
+    life_time = 180,
+    pictures = particle_animations.get_gleba_tree_leaf_particle_pictures({tint = {0.5725, 0.6392, 0.8667, 1.0}, tint_as_overlay = true, scale = 1.2}),
+    shadows = particle_animations.get_gleba_tree_leaf_particle_pictures({ tint = shadowtint(), shift = util.by_pixel (1,0), scale = 1.1}),
+    regular_trigger_effect = nil,
+    ended_in_water_trigger_effect = particle_ended_in_water_trigger_effect(),
+    render_layer_when_on_ground = "lower-object-above-shadow",
+    movement_modifier = 0.85
+  },
+
+  make_particle
+  {
+    name = "hairyclubnub-branch-particle",
+    life_time = 120,
+    pictures = particle_animations.get_gleba_tree_wooden_particle_pictures({tint = {1.0, 0.898, 0.6471, 1.0}}),
+    shadows = particle_animations.get_gleba_tree_wooden_particle_pictures({ tint = shadowtint(), shift = util.by_pixel (1,0)}),
+    regular_trigger_effect_frequency = 4,
+    regular_trigger_effect = gleba_tree_grey_sap_trigger_effect(),
+    ended_in_water_trigger_effect = particle_ended_in_water_trigger_effect(),
+    render_layer_when_on_ground = "lower-object-above-shadow"
+  },
+
+  make_particle
+  {
+    name = "hairyclubnub-mining-particle",
+    life_time = 120,
+    pictures = particle_animations.get_gleba_tree_wooden_particle_pictures({tint = {1.0, 0.898, 0.6471, 1.0}, scale = 0.7}),
+    shadows = particle_animations.get_gleba_tree_wooden_particle_pictures({ tint = shadowtint(), shift = util.by_pixel (1,0), scale = 0.7}),
+    regular_trigger_effect = nil,
+    ended_in_water_trigger_effect = particle_ended_in_water_trigger_effect(),
+    render_layer_when_on_ground = "lower-object-above-shadow"
+  },
+
+  --teflilly
+
+  make_particle
+  {
+    name = "teflilly-leaf-particle",
+    life_time = 180,
+    pictures = particle_animations.get_gleba_tree_leaf_particle_2_pictures({tint = {0.8118, 0.4392, 0.4471, 1.0}, tint_as_overlay = true, scale = 1.4}),
+    shadows = particle_animations.get_gleba_tree_leaf_particle_2_pictures({ tint = shadowtint(), shift = util.by_pixel (1,0), scale = 1.4}),
+    regular_trigger_effect_frequency = 6,
+    regular_trigger_effect = gleba_tree_leaf_trigger_effect(),
+    ended_in_water_trigger_effect = nil,
+    render_layer_when_on_ground = "lower-object-above-shadow",
+    movement_modifier = 0.9,
+    render_layer = "higher-object-above"
+  },
+
+  make_particle
+  {
+    name = "teflilly-branch-particle",
+    life_time = 120,
+    pictures = particle_animations.get_gleba_tree_wooden_particle_pictures({tint = {0.4588, 0.4078, 0.3569, 1.0}, tint_as_overlay = true, scale = 0.8}),
+    shadows = particle_animations.get_gleba_tree_wooden_particle_pictures({ tint = shadowtint(), shift = util.by_pixel (1,0), scale = 0.8}),
+    regular_trigger_effect =  small_dust_smoke_trigger_effect(),
+    ended_in_water_trigger_effect = particle_ended_in_water_trigger_effect(),
+    render_layer_when_on_ground = "lower-object-above-shadow"
+  },
+
+  make_particle
+  {
+    name = "teflilly-mining-particle",
+    life_time = 120,
+    pictures = particle_animations.get_gleba_tree_wooden_particle_pictures({tint = {0.4588, 0.4078, 0.3569, 1.0}, tint_as_overlay = true, scale = 0.5}),
+    shadows = particle_animations.get_gleba_tree_wooden_particle_pictures({ tint = shadowtint(), shift = util.by_pixel (1,0), scale = 0.5}),
+    regular_trigger_effect =  small_dust_smoke_trigger_effect(),
+    ended_in_water_trigger_effect = particle_ended_in_water_trigger_effect(),
+    render_layer_when_on_ground = "lower-object-above-shadow"
+  },
+
+  --lickmaw
+
+  make_particle
+  {
+    name = "lickmaw-leaf-particle",
+    life_time = 120,
+    pictures = particle_animations.get_gleba_tree_crop_particle_pictures({tint = {0.7843, 0.2196, 0.2196, 1.0}, tint_as_overlay = true, scale = 0.25}),
+    shadows = particle_animations.get_gleba_tree_crop_particle_pictures({ tint = shadowtint(), shift = util.by_pixel (1,0), scale = 0.25}),
+    regular_trigger_effect_frequency = 3,
+    regular_trigger_effect = gleba_tree_red_sap_trigger_effect(),
+    ended_in_water_trigger_effect = particle_ended_in_water_trigger_effect(),
+    render_layer_when_on_ground = "lower-object-above-shadow"
+  },
+
+  make_particle
+  {
+    name = "lickmaw-branch-particle",
+    life_time = 120,
+    pictures = particle_animations.get_gleba_tree_wooden_particle_pictures({tint = {0.5961, 0.5451, 0.5647, 1.0}, tint_as_overlay = true }),
+    shadows = particle_animations.get_gleba_tree_wooden_particle_pictures({ tint = shadowtint(), shift = util.by_pixel (1,0)}),
+    regular_trigger_effect = gleba_tree_red_smoke_trigger_effect(),
+    ended_in_water_trigger_effect = particle_ended_in_water_trigger_effect(),
+    render_layer_when_on_ground = "lower-object-above-shadow",
+    --render_layer = "higher-object-above"
+  },
+
+  make_particle
+  {
+    name = "lickmaw-mining-particle",
+    life_time = 120,
+    pictures = particle_animations.get_gleba_tree_crop_particle_pictures({tint = {0.5961, 0.5451, 0.5647, 1.0}, tint_as_overlay = true, scale = 0.5}),
+    shadows = particle_animations.get_gleba_tree_crop_particle_pictures({ tint = shadowtint(), shift = util.by_pixel (1,0), scale = 0.5}),
+    regular_trigger_effect_frequency = 4,
+    regular_trigger_effect = gleba_tree_red_sap_trigger_effect(),
+    ended_in_water_trigger_effect = particle_ended_in_water_trigger_effect(),
+    render_layer_when_on_ground = "lower-object-above-shadow",
+
+  },
+
+  --stingfrond
+
+  make_particle
+  {
+    name = "stingfrond-leaf-particle",
+    life_time = 180,
+    pictures = particle_animations.get_gleba_tree_leaf_particle_pictures({ tint = {0.651, 1.0, 0.9804, 1.0}, tint_as_overlay = true, scale = 1.2}),
+    shadows = particle_animations.get_gleba_tree_leaf_particle_pictures({ tint = shadowtint(), shift = util.by_pixel (1,0), scale = 1.2}),
+    regular_trigger_effect = nil, 
+    ended_in_water_trigger_effect = particle_ended_in_water_trigger_effect(),
+    render_layer_when_on_ground = "lower-object-above-shadow",
+    movement_modifier = 0.95,
+    render_layer = "higher-object-above"
+
+  },
+
+  make_particle
+  {
+    name = "stingfrond-branch-particle",
+    life_time = 120,
+    pictures = particle_animations.get_gleba_tree_wooden_particle_pictures({tint = {0.298, 0.4314, 0.4275, 1.0}, tint_as_overlay = true}),
+    shadows = particle_animations.get_gleba_tree_wooden_particle_pictures({ tint = shadowtint(), shift = util.by_pixel (1,0)}),
+    regular_trigger_effect = gleba_tree_blue_smoke_trigger_effect(),
+    ended_in_water_trigger_effect = particle_ended_in_water_trigger_effect(),
+    render_layer_when_on_ground = "lower-object-above-shadow",
+    render_layer = "higher-object-under"
+  },
+
+  make_particle
+  {
+    name = "stingfrond-mining-particle",
+    life_time = 120,
+    pictures = particle_animations.get_gleba_tree_wooden_particle_pictures({tint = {0.298, 0.4314, 0.4275, 1.0}, tint_as_overlay = true, scale = 0.5}),
+    shadows = particle_animations.get_gleba_tree_wooden_particle_pictures({ tint = shadowtint(), shift = util.by_pixel (1,0), scale = 0.5}),
+    regular_trigger_effect = gleba_tree_blue_smoke_trigger_effect(),
+    ended_in_water_trigger_effect = particle_ended_in_water_trigger_effect(),
+    render_layer_when_on_ground = "lower-object-above-shadow"
+  },
+
+  --boompuff
+
+  make_particle
+  {
+    name = "boompuff-leaf-particle",
+    life_time = 120,
+    pictures = particle_animations.get_gleba_tree_spongy_particle_pictures({tint = {0.7451, 0.3882, 0.149, 1.0}, tint_as_overlay = true, scale = 1}),
+    shadows = particle_animations.get_gleba_tree_spongy_particle_pictures({ tint = shadowtint(), shift = util.by_pixel (1,0), scale = 1}),
+    regular_trigger_effect = gleba_tree_orange_smoke_trigger_effect(),
+    ended_in_water_trigger_effect = particle_ended_in_water_trigger_effect(),
+    render_layer_when_on_ground = "lower-object-above-shadow"
+  },
+
+  make_particle
+  {
+    name = "boompuff-branch-particle",
+    life_time = 120,
+    pictures = particle_animations.get_gleba_tree_wooden_particle_pictures({tint = {0.6706, 0.5255, 0.3451, 1.0}, tint_as_overlay = true, scale = 1.2}),
+    shadows = particle_animations.get_gleba_tree_wooden_particle_pictures({ tint = shadowtint(), shift = util.by_pixel (1,0), scale = 1.2}),
+    regular_trigger_effect = small_dust_smoke_trigger_effect(),
+    ended_in_water_trigger_effect = particle_ended_in_water_trigger_effect(),
+    render_layer_when_on_ground = "lower-object-above-shadow"
+  },
+
+  make_particle
+  {
+    name = "boompuff-mining-particle",
+    life_time = 120,
+    pictures = particle_animations.get_gleba_tree_wooden_particle_pictures({tint = {0.6706, 0.5255, 0.3451, 1.0}, tint_as_overlay = true, scale = 0.5}),
+    shadows = particle_animations.get_gleba_tree_wooden_particle_pictures({ tint = shadowtint(), shift = util.by_pixel (1,0), scale = 0.5}),
+    regular_trigger_effect = small_dust_smoke_trigger_effect(),
+    ended_in_water_trigger_effect = particle_ended_in_water_trigger_effect(),
+    render_layer_when_on_ground = "lower-object-above-shadow"
+  },
+
+  --sunnycomb
+
+  make_particle
+  {
+    name = "sunnycomb-leaf-particle",
+    life_time = 120,
+    pictures = particle_animations.get_gleba_tree_crop_particle_pictures({tint = {1.0, 0.8471, 0.1412, 1.0}, tint_as_overlay = true, scale = 0.4}),
+    shadows = particle_animations.get_gleba_tree_crop_particle_pictures({ tint = shadowtint(), shift = util.by_pixel (1,0), scale = 0.4,}),
+    regular_trigger_effect = nil,
+    ended_in_water_trigger_effect = particle_ended_in_water_trigger_effect(),
+    render_layer_when_on_ground = "lower-object-above-shadow"
+  },
+
+  make_particle
+  {
+    name = "sunnycomb-branch-particle",
+    life_time = 120,
+    pictures = particle_animations.get_gleba_tree_spongy_particle_pictures({tint =  {0.451, 0.3804, 0.2118, 1.0}, tint_as_overlay = true, scale = 1.2}),
+    shadows = particle_animations.get_gleba_tree_spongy_particle_pictures({ tint = shadowtint(), shift = util.by_pixel (1,0), scale = 1.2,}),
+    regular_trigger_effect = small_dust_smoke_trigger_effect(),
+    ended_in_water_trigger_effect = particle_ended_in_water_trigger_effect(),
+    render_layer_when_on_ground = "lower-object-above-shadow"
+  },
+
+  make_particle
+  {
+    name = "sunnycomb-mining-particle",
+    life_time = 120,
+    pictures = particle_animations.get_gleba_tree_spongy_particle_pictures({tint = {0.451, 0.3804, 0.2118, 1.0}, tint_as_overlay = tru, scale = 0.5}),
+    shadows = particle_animations.get_gleba_tree_spongy_particle_pictures({ tint = shadowtint(), shift = util.by_pixel (1,0), scele = 0.5}),
+    regular_trigger_effect = small_dust_smoke_trigger_effect(),
+    ended_in_water_trigger_effect = particle_ended_in_water_trigger_effect(),
+    render_layer_when_on_ground = "lower-object-above-shadow"
+  },
+
+  --water-cane
+
+  make_particle
+  {
+    name = "water-cane-branch-particle",
+    life_time = 180,
+    pictures = particle_animations.get_gleba_water_cane_particle_pictures({tint = {0.7843, 0.7216, 0.5333, 1.0}, tint_as_overlay = true, scale = 0.8}),
+    shadows = particle_animations.get_gleba_water_cane_particle_pictures({ tint = shadowtint(), shift = util.by_pixel (1,0), scale = 0.8}),
+    regular_trigger_effect = nil,
+    ended_in_water_trigger_effect = particle_ended_in_water_trigger_effect(),
+    render_layer_when_on_ground = "lower-object-above-shadow"
+  },
 }
 
 data:extend(particles)
 
-
 local blood_particles = {
   "blood-particle-small",
   "blood-particle",
