@@ -91,7 +91,7 @@ data:extend(
       }
     },
     subgroup = "agriculture-processes",
-    order = "e[bacteria]-a[bacteria]-b[copper]",
+    order = "b[agriculture]-d[bacteria]-c[copper-bacteria]",
     enabled = false,
     allow_productivity = true,
     energy_required = 1,
@@ -104,6 +104,7 @@ data:extend(
       {type = "item", name = "copper-bacteria", amount = 1, probability = 0.1 },
       {type = "item", name = "spoilage", amount = 1}
     },
+    main_product = "copper-bacteria",
     crafting_machine_tint =
     {
       primary = {r = 1.000, g = 0.457, b = 0.000, a = 1.000}, -- #ff7400ff
@@ -125,10 +126,10 @@ data:extend(
       }
     },
     subgroup = "agriculture-processes",
-    order = "e[bacteria]-b[cultivation]-b[copper]",
+    order = "b[agriculture]-d[bacteria]-d[copper-bacteria-cultivation]",
     enabled = false,
     allow_productivity = true,
-    result_is_always_fresh = true,
+    reset_freshness_on_craft = true,
     energy_required = 4,
     ingredients =
     {
@@ -161,7 +162,7 @@ data:extend(
       }
     },
     subgroup = "agriculture-processes",
-    order = "e[bacteria]-a[bacteria]-a[iron]",
+    order = "b[agriculture]-d[bacteria]-a[iron-bacteria]",
     enabled = false,
     allow_productivity = true,
     energy_required = 1,
@@ -174,10 +175,11 @@ data:extend(
       {type = "item", name = "iron-bacteria", amount = 1, probability = 0.1 },
       {type = "item", name = "spoilage", amount = 4}
     },
+    main_product = "iron-bacteria",
     crafting_machine_tint =
     {
-      primary = {r = 0.000, g = 0.500, b = 1.000, a = 1.000}, -- #007fffff
-      secondary = {r = 0.095, g = 0.412, b = 0.822, a = 1.000}, -- #1868d1ff
+      primary = {r = 0.000, g = 0.500, b = 1.000, a = 1.000},
+      secondary = {r = 0.095, g = 0.412, b = 0.822, a = 1.000},
     }
   },
 
@@ -195,10 +197,10 @@ data:extend(
       }
     },
     subgroup = "agriculture-processes",
-    order = "e[bacteria]-b[cultivation]-a[iron]",
+    order = "b[agriculture]-d[bacteria]-b[iron-bacteria-cultivation]",
     enabled = false,
     allow_productivity = true,
-    result_is_always_fresh = true,
+    reset_freshness_on_craft = true,
     energy_required = 4,
     ingredients =
     {
@@ -324,7 +326,7 @@ data:extend(
     icon = "__space-age__/graphics/icons/nutrients-from-spoilage.png",
     category = "organic-or-assembling",
     subgroup = "agriculture-processes",
-    order = "c[nutrients]-a[nutrients-from-spoilage]",
+    order = "c[nutrients]-c[nutrients-from-spoilage]",
     enabled = false,
     allow_productivity = true,
     energy_required = 2,
@@ -344,7 +346,7 @@ data:extend(
     subgroup = "agriculture-processes",
     enabled = false,
     allow_productivity = true,
-    order = "c[nutrients]-b[nutrients-from-yumako-mash]",
+    order = "c[nutrients]-d[nutrients-from-yumako-mash]",
     energy_required = 4,
     ingredients = {{type = "item", name = "yumako-mash", amount = 4}},
     results = {{type="item", name="nutrients", amount=6}},
@@ -362,14 +364,14 @@ data:extend(
     subgroup = "agriculture-processes",
     enabled = false,
     allow_productivity = true,
-    order = "c[nutrients]-c[nutrients-from-bioflux]",
+    order = "c[nutrients]-e[nutrients-from-bioflux]",
     energy_required = 2,
     ingredients = {{type = "item", name = "bioflux", amount = 5}},
     results = {{type="item", name="nutrients", amount=40}},
     crafting_machine_tint =
     {
       primary = {r = 0.8, g = 0.9, b = 1, a = 1.000},
-      secondary = {r = 0.900, g = 0.137, b = 0.000, a = 1.000}, -- #e52200ff
+      secondary = {r = 0.900, g = 0.137, b = 0.000, a = 1.000},
     }
   },
 
@@ -391,7 +393,7 @@ data:extend(
     auto_recycle = false,
     enabled = false,
     allow_productivity = true,
-    result_is_always_fresh = true,
+    reset_freshness_on_craft = true,
     hide_from_signal_gui = true,
     energy_required = 15,
     ingredients =
@@ -406,8 +408,8 @@ data:extend(
     },
     crafting_machine_tint =
     {
-      primary = {r = 0.5, g = 0.9, b = 0.5, a = 1.000},
-      secondary = {r = 0.0, g = 0.5, b = 0.0, a = 1.000},
+      primary = {r = 45, g = 129, b = 86, a = 1.000},
+      secondary = {r = 122, g = 75, b = 156, a = 1.000},
     }
   },
 
@@ -431,7 +433,7 @@ data:extend(
     results = {{type="item", name="rocket-fuel", amount=1}},
     crafting_machine_tint =
     {
-      primary = {r = 0.728, g = 0.116, b = 0.116, a = 1.000}, -- #b91d1dff
+      primary = {r = 151, g = 66, b = 0, a = 1.000},
       secondary = {r = 0.3, g = 0.9, b = 0.3, a = 1.000},
     }
   },
@@ -479,8 +481,8 @@ data:extend(
     results = {{type="item", name="plastic-bar", amount=3}},
     crafting_machine_tint =
     {
-      primary = {r = 0.722, g = 0.621, b = 0.655, a = 1.000},
-      secondary = {r = 0.693, g = 0.449, b = 0.449, a = 1.000},
+      primary = {r = 189, g = 31, b = 50, a = 1.000},
+      secondary = {r = 235, g = 83, b = 0, a = 1.000},
     }
   },
   {
@@ -502,7 +504,7 @@ data:extend(
     results = {{type="item", name="sulfur", amount=2}},
     crafting_machine_tint =
     {
-      primary = {r = 1, g = 1, b = 0, a = 1.000},
+      primary = {r = 193, g = 164, b = 0, a = 1.000},
       secondary = {r = 0.693, g = 0.449, b = 0.0, a = 1.000},
     }
   },
@@ -550,8 +552,8 @@ data:extend(
     allow_productivity = true,
     crafting_machine_tint =
     {
-      primary = {r = 0.306, g = 0.643, b = 0.684, a = 1.000},
-      secondary = {r = 0.684, g = 0.684, b = 0.684, a = 1.000},
+      primary = {r = 9, g = 0, b = 220, a = 1.000},
+      secondary = {r = 0, g = 0, b = 0, a = 1.000},
     },
   },
 
@@ -803,8 +805,8 @@ data:extend(
     allow_productivity = true,
     crafting_machine_tint =
     {
-      primary = {0.1, 0.2, 0.0, 1},
-      secondary = {0.639, 0.764, 1, 1}
+      primary = {0.95, 1, 0, 1},
+      secondary = {255, 233, 163, 1}
     }
   },
   {
@@ -1429,11 +1431,15 @@ data:extend(
   },
   {
     type = "recipe",
-    name = "molten-iron",
+    name = "molten-iron", -- TODO: to be renamed into "iron-ore-melting" in 2.1
+    localised_name = {"recipe-name.iron-ore-melting"},
+    icon = "__space-age__/graphics/icons/iron-ore-melting.png",
     category = "metallurgy",
     subgroup = "vulcanus-processes",
     order = "a[melting]-b[molten-iron]",
     auto_recycle = false,
+    show_amount_in_title = false,
+    always_show_products = true,
     enabled = false,
     ingredients =
     {
@@ -1451,11 +1457,15 @@ data:extend(
   },
   {
     type = "recipe",
-    name = "molten-copper",
+    name = "molten-copper", -- TODO: to be renamed into "copper-ore-melting" in 2.1
+    localised_name = {"recipe-name.copper-ore-melting"},
+    icon = "__space-age__/graphics/icons/copper-ore-melting.png",
     category = "metallurgy",
     subgroup = "vulcanus-processes",
     order = "a[melting]-c[molten-copper]",
     auto_recycle = false,
+    show_amount_in_title = false,
+    always_show_products = true,
     enabled = false,
     ingredients =
     {
@@ -1910,8 +1920,8 @@ data:extend(
     enabled = false,
     crafting_machine_tint =
     {
-      primary = {r = 0.134, g = 0.009, b = 0.009, a = 1.000}, -- #220202ff
-      secondary = {r = 0.377, g = 0.255, b = 0.255, a = 1.000}, -- #604141ff
+      primary = {r = 0.134, g = 0.009, b = 0.009, a = 1.000},
+      secondary = {r = 0.377, g = 0.255, b = 0.255, a = 1.000},
     }
   },
 
@@ -1936,10 +1946,10 @@ data:extend(
     allow_decomposition = false,
     crafting_machine_tint =
     {
-      primary = {r = 0.207, g = 0.177, b = 0.177, a = 1.000}, -- #342d2dff
-      secondary = {r = 0.301, g = 0.276, b = 0.196, a = 1.000}, -- #4c4632ff
-      tertiary = {r = 0.790, g = 0.722, b = 0.478, a = 1.000}, -- #c9b879ff
-      quaternary = {r = 0.554, g = 0.540, b = 0.540, a = 1.000}, -- #8d8989ff
+      primary = {r = 0.207, g = 0.177, b = 0.177, a = 1.000},
+      secondary = {r = 0.301, g = 0.276, b = 0.196, a = 1.000},
+      tertiary = {r = 0.790, g = 0.722, b = 0.478, a = 1.000},
+      quaternary = {r = 0.554, g = 0.540, b = 0.540, a = 1.000},
     }
   },
   {
@@ -1977,7 +1987,7 @@ data:extend(
     category = "cryogenics",
     energy_required = 10,
     enabled = false,
-    result_is_always_fresh = true,
+    reset_freshness_on_craft = true,
     ingredients =
     {
       {type = "item", name = "biter-egg", amount = 10},
@@ -2011,7 +2021,7 @@ data:extend(
     category = "organic-or-chemistry",
     subgroup = "nauvis-agriculture",
     order = "b[nauvis-agriculture]-b[fish-breeding]",
-    result_is_always_fresh = true,
+    reset_freshness_on_craft = true,
     auto_recycle = false,
     energy_required = 6,
     enabled = false,
@@ -2055,8 +2065,8 @@ data:extend(
     allow_quality = false,
     crafting_machine_tint =
     {
-      primary = {1, 0, 0, 1},
-      secondary = {1, 0, 0, 1}
+      primary = {166, 182, 181, 1},
+      secondary = {1, 0, 0, 0.3}
     }
   },
   {
@@ -2075,8 +2085,8 @@ data:extend(
     allow_quality = false,
     crafting_machine_tint =
     {
-      primary = {r = 1, g = 0, b = 0.25, a = 1},
-      secondary = {r = 1, g = 0, b = 0.25, a = 1},
+      primary = {r = 130, g = 130, b = 120, a = 1},
+      secondary = {r = 194, g = 162, b = 117, a = 1},
     },
   },
   -------------------------------------------------------------------------- Fulgora
@@ -2757,10 +2767,10 @@ data:extend(
   {
     type = "recipe",
     name = "wood-processing",
-    icon = "__base__/graphics/icons/tree-08.png",
+    icon = "__base__/graphics/icons/wood-processing.png",
     category = "organic-or-assembling",
     subgroup = "nauvis-agriculture",
-    order = "b[nauvis-agriculture]-a[wood-processing]",
+    order = "a[seeds]-a[wood-processing]",
     enabled = false,
     allow_productivity = true,
     energy_required = 2,
